@@ -16,6 +16,7 @@ extensions = [
     "sphinx.ext.autodoc",
     "sphinx.ext.napoleon",
     "sphinx.ext.intersphinx",
+    "sphinx.ext.extlinks",
     "sphinx_rtd_theme",
     "sphinx_codeautolink",
 ]
@@ -34,3 +35,6 @@ intersphinx_mapping = {
     "numpy": ("https://numpy.org/doc/stable/", None),
     "matplotlib": ("https://matplotlib.org/stable/", None),
 }
+extlinks = {
+    'issue': ('https://github.com/felix-hilden/sphinx-codeautolink/issues/%s', '#'),
+}
